@@ -64,7 +64,7 @@ constexpr size_t max_preferred_versionslen = 4;
 Config config{};
 
 Stream::Stream(const Request &req, int64_t stream_id)
-    : req(req), stream_id(stream_id), fd(-1) {
+  : req(req), stream_id(stream_id), fd(-1) {
   nghttp3_buf_init(&reqbuf);
 }
 
@@ -176,18 +176,18 @@ void siginthandler(struct ev_loop *loop, ev_signal *w, int revents) {
 
 Client::Client(struct ev_loop *loop, uint32_t client_chosen_version,
                uint32_t original_version)
-    : remote_addr_{},
-      loop_(loop),
-      addr_(nullptr),
-      port_(nullptr),
-      nstreams_done_(0),
-      nstreams_closed_(0),
-      nkey_update_(0),
-      client_chosen_version_(client_chosen_version),
-      original_version_(original_version),
-      early_data_(false),
-      handshake_confirmed_(false),
-      tx_{} {
+  : remote_addr_{},
+    loop_(loop),
+    addr_(nullptr),
+    port_(nullptr),
+    nstreams_done_(0),
+    nstreams_closed_(0),
+    nkey_update_(0),
+    client_chosen_version_(client_chosen_version),
+    original_version_(original_version),
+    early_data_(false),
+    handshake_confirmed_(false),
+    tx_{} {
   ev_io_init(&wev_, writecb, 0, EV_WRITE);
   wev_.data = this;
   ev_timer_init(&timer_, timeoutcb, 0., 0.);
@@ -319,14 +319,14 @@ int Client::handshake_completed() {
 
   if (config.tp_file) {
     std::array<uint8_t, 256> data;
-    auto datalen = ngtcp2_conn_encode_0rtt_transport_params(conn_, data.data(),
-                                                            data.size());
+    auto datalen =
+      ngtcp2_conn_encode_0rtt_transport_params(conn_, data.data(), data.size());
     if (datalen < 0) {
       std::cerr << "Could not encode 0-RTT transport parameters: "
                 << ngtcp2_strerror(datalen) << std::endl;
     } else if (util::write_transport_params(
-                   config.tp_file,
-                   {data.data(), static_cast<size_t>(datalen)}) != 0) {
+                 config.tp_file, {data.data(), static_cast<size_t>(datalen)}) !=
+               0) {
       std::cerr << "Could not write transport parameters in " << config.tp_file
                 << std::endl;
     }
@@ -436,8 +436,8 @@ int get_new_connection_id(ngtcp2_conn *conn, ngtcp2_cid *cid, uint8_t *token,
 
   cid->datalen = cidlen;
   if (ngtcp2_crypto_generate_stateless_reset_token(
-          token, config.static_secret.data(), config.static_secret.size(),
-          cid) != 0) {
+        token, config.static_secret.data(), config.static_secret.size(), cid) !=
+      0) {
     return NGTCP2_ERR_CALLBACK_FAILURE;
   }
 
@@ -601,46 +601,46 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
   port_ = port;
 
   auto callbacks = ngtcp2_callbacks{
-      ngtcp2_crypto_client_initial_cb,
-      nullptr, // recv_client_initial
-      ::recv_crypto_data,
-      ::handshake_completed,
-      ::recv_version_negotiation,
-      ngtcp2_crypto_encrypt_cb,
-      ngtcp2_crypto_decrypt_cb,
-      do_hp_mask,
-      ::recv_stream_data,
-      ::acked_stream_data_offset,
-      nullptr, // stream_open
-      stream_close,
-      nullptr, // recv_stateless_reset
-      ngtcp2_crypto_recv_retry_cb,
-      extend_max_local_streams_bidi,
-      nullptr, // extend_max_local_streams_uni
-      rand,
-      get_new_connection_id,
-      nullptr, // remove_connection_id
-      ::update_key,
-      path_validation,
-      ::select_preferred_address,
-      nullptr, // stream_reset
-      nullptr, // extend_max_remote_streams_bidi,
-      nullptr, // extend_max_remote_streams_uni,
-      ::extend_max_stream_data,
-      nullptr, // dcid_status
-      ::handshake_confirmed,
-      ::recv_new_token,
-      ngtcp2_crypto_delete_crypto_aead_ctx_cb,
-      ngtcp2_crypto_delete_crypto_cipher_ctx_cb,
-      nullptr, // recv_datagram
-      nullptr, // ack_datagram
-      nullptr, // lost_datagram
-      ngtcp2_crypto_get_path_challenge_data_cb,
-      nullptr, // stream_stop_sending
-      ngtcp2_crypto_version_negotiation_cb,
-      nullptr, // recv_rx_key
-      nullptr, // recv_tx_key
-      ::early_data_rejected,
+    ngtcp2_crypto_client_initial_cb,
+    nullptr, // recv_client_initial
+    ::recv_crypto_data,
+    ::handshake_completed,
+    ::recv_version_negotiation,
+    ngtcp2_crypto_encrypt_cb,
+    ngtcp2_crypto_decrypt_cb,
+    do_hp_mask,
+    ::recv_stream_data,
+    ::acked_stream_data_offset,
+    nullptr, // stream_open
+    stream_close,
+    nullptr, // recv_stateless_reset
+    ngtcp2_crypto_recv_retry_cb,
+    extend_max_local_streams_bidi,
+    nullptr, // extend_max_local_streams_uni
+    rand,
+    get_new_connection_id,
+    nullptr, // remove_connection_id
+    ::update_key,
+    path_validation,
+    ::select_preferred_address,
+    nullptr, // stream_reset
+    nullptr, // extend_max_remote_streams_bidi,
+    nullptr, // extend_max_remote_streams_uni,
+    ::extend_max_stream_data,
+    nullptr, // dcid_status
+    ::handshake_confirmed,
+    ::recv_new_token,
+    ngtcp2_crypto_delete_crypto_aead_ctx_cb,
+    ngtcp2_crypto_delete_crypto_cipher_ctx_cb,
+    nullptr, // recv_datagram
+    nullptr, // ack_datagram
+    nullptr, // lost_datagram
+    ngtcp2_crypto_get_path_challenge_data_cb,
+    nullptr, // stream_stop_sending
+    ngtcp2_crypto_version_negotiation_cb,
+    nullptr, // recv_rx_key
+    nullptr, // recv_tx_key
+    ::early_data_rejected,
   };
 
   ngtcp2_cid scid, dcid;
@@ -731,7 +731,7 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
 
     if (!config.max_udp_payload_size) {
       settings.max_tx_udp_payload_size = *std::max_element(
-          std::begin(config.pmtud_probes), std::end(config.pmtud_probes));
+        std::begin(config.pmtud_probes), std::end(config.pmtud_probes));
     }
   }
 
@@ -739,7 +739,7 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
   ngtcp2_transport_params_default(&params);
   params.initial_max_stream_data_bidi_local = config.max_stream_data_bidi_local;
   params.initial_max_stream_data_bidi_remote =
-      config.max_stream_data_bidi_remote;
+    config.max_stream_data_bidi_remote;
   params.initial_max_stream_data_uni = config.max_stream_data_uni;
   params.initial_max_data = config.max_data;
   params.initial_max_streams_bidi = config.max_streams_bidi;
@@ -749,19 +749,19 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
   params.grease_quic_bit = 1;
 
   auto path = ngtcp2_path{
-      {
-          const_cast<sockaddr *>(&ep.addr.su.sa),
-          ep.addr.len,
-      },
-      {
-          const_cast<sockaddr *>(&remote_addr.su.sa),
-          remote_addr.len,
-      },
-      &ep,
+    {
+      const_cast<sockaddr *>(&ep.addr.su.sa),
+      ep.addr.len,
+    },
+    {
+      const_cast<sockaddr *>(&remote_addr.su.sa),
+      remote_addr.len,
+    },
+    &ep,
   };
-  auto rv = ngtcp2_conn_client_new(&conn_, &dcid, &scid, &path,
-                                   client_chosen_version_, &callbacks,
-                                   &settings, &params, nullptr, this);
+  auto rv =
+    ngtcp2_conn_client_new(&conn_, &dcid, &scid, &path, client_chosen_version_,
+                           &callbacks, &settings, &params, nullptr, this);
 
   if (rv != 0) {
     std::cerr << "ngtcp2_conn_client_new: " << ngtcp2_strerror(rv) << std::endl;
@@ -781,8 +781,8 @@ int Client::init(int fd, const Address &local_addr, const Address &remote_addr,
       early_data_ = false;
     } else {
       auto rv = ngtcp2_conn_decode_and_set_0rtt_transport_params(
-          conn_, reinterpret_cast<const uint8_t *>(params->data()),
-          params->size());
+        conn_, reinterpret_cast<const uint8_t *>(params->data()),
+        params->size());
       if (rv != 0) {
         std::cerr << "ngtcp2_conn_decode_and_set_0rtt_transport_params:"
                   << ngtcp2_strerror(rv) << std::endl;
@@ -804,15 +804,15 @@ int Client::feed_data(const Endpoint &ep, const sockaddr *sa, socklen_t salen,
                       const ngtcp2_pkt_info *pi,
                       std::span<const uint8_t> data) {
   auto path = ngtcp2_path{
-      {
-          const_cast<sockaddr *>(&ep.addr.su.sa),
-          ep.addr.len,
-      },
-      {
-          const_cast<sockaddr *>(sa),
-          salen,
-      },
-      const_cast<Endpoint *>(&ep),
+    {
+      const_cast<sockaddr *>(&ep.addr.su.sa),
+      ep.addr.len,
+    },
+    {
+      const_cast<sockaddr *>(sa),
+      salen,
+    },
+    const_cast<Endpoint *>(&ep),
   };
   if (auto rv = ngtcp2_conn_read_pkt(conn_, &path, pi, data.data(), data.size(),
                                      util::timestamp());
@@ -821,7 +821,7 @@ int Client::feed_data(const Endpoint &ep, const sockaddr *sa, socklen_t salen,
     if (!last_error_.error_code) {
       if (rv == NGTCP2_ERR_CRYPTO) {
         ngtcp2_ccerr_set_tls_alert(
-            &last_error_, ngtcp2_conn_get_tls_alert(conn_), nullptr, 0);
+          &last_error_, ngtcp2_conn_get_tls_alert(conn_), nullptr, 0);
       } else {
         ngtcp2_ccerr_set_liberr(&last_error_, rv, nullptr, 0);
       }
@@ -847,7 +847,7 @@ int Client::on_read(const Endpoint &ep) {
   msg.msg_iov = &msg_iov;
   msg.msg_iovlen = 1;
 
-  uint8_t msg_ctrl[CMSG_SPACE(sizeof(int)) + CMSG_SPACE(sizeof(uint16_t))];
+  uint8_t msg_ctrl[CMSG_SPACE(sizeof(int)) + CMSG_SPACE(sizeof(int))];
   msg.msg_control = msg_ctrl;
 
   for (;;) {
@@ -972,8 +972,8 @@ int Client::write_streams() {
   size_t pktcnt = 0;
   auto max_udp_payload_size = ngtcp2_conn_get_max_tx_udp_payload_size(conn_);
   auto max_pktcnt =
-      std::max(ngtcp2_conn_get_send_quantum(conn_) / max_udp_payload_size,
-               static_cast<size_t>(1));
+    std::max(ngtcp2_conn_get_send_quantum(conn_) / max_udp_payload_size,
+             static_cast<size_t>(1));
   auto ts = util::timestamp();
 
   ngtcp2_path_storage_zero(&ps);
@@ -998,8 +998,8 @@ int Client::write_streams() {
     ngtcp2_pkt_info pi;
 
     auto nwrite = ngtcp2_conn_writev_stream(
-        conn_, &ps.path, &pi, tx_.data.data(), max_udp_payload_size, &ndatalen,
-        flags, stream_id, &vec, vcnt, ts);
+      conn_, &ps.path, &pi, tx_.data.data(), max_udp_payload_size, &ndatalen,
+      flags, stream_id, &vec, vcnt, ts);
     if (nwrite < 0) {
       switch (nwrite) {
       case NGTCP2_ERR_STREAM_DATA_BLOCKED:
@@ -1140,7 +1140,7 @@ int bind_addr(Address &local_addr, int fd, const in_addr_union *iau,
   return 0;
 }
 } // namespace
-#endif // HAVE_LINUX_RTNETLINK_H
+#endif // defined(HAVE_LINUX_RTNETLINK_H)
 
 #ifndef HAVE_LINUX_RTNETLINK_H
 namespace {
@@ -1161,7 +1161,7 @@ int connect_sock(Address &local_addr, int fd, const Address &remote_addr) {
   return 0;
 }
 } // namespace
-#endif // !HAVE_LINUX_RTNETLINK_H
+#endif // !defined(HAVE_LINUX_RTNETLINK_H)
 
 namespace {
 int udp_sock(int family) {
@@ -1233,7 +1233,7 @@ std::optional<Endpoint *> Client::endpoint_for(const Address &remote_addr) {
   if (addreq(&current_ep->addr.su.sa, iau)) {
     return current_ep;
   }
-#endif // HAVE_LINUX_RTNETLINK_H
+#endif // defined(HAVE_LINUX_RTNETLINK_H)
 
   auto fd = udp_sock(remote_addr.su.sa.sa_family);
   if (fd == -1) {
@@ -1247,12 +1247,12 @@ std::optional<Endpoint *> Client::endpoint_for(const Address &remote_addr) {
     close(fd);
     return nullptr;
   }
-#else  // !HAVE_LINUX_RTNETLINK_H
+#else  // !defined(HAVE_LINUX_RTNETLINK_H)
   if (connect_sock(local_addr, fd, remote_addr) != 0) {
     close(fd);
     return nullptr;
   }
-#endif // !HAVE_LINUX_RTNETLINK_H
+#endif // !defined(HAVE_LINUX_RTNETLINK_H)
 
   endpoints_.emplace_back();
   auto &ep = endpoints_.back();
@@ -1296,12 +1296,12 @@ int Client::change_local_addr() {
     close(nfd);
     return -1;
   }
-#else  // !HAVE_LINUX_RTNETLINK_H
+#else  // !defined(HAVE_LINUX_RTNETLINK_H)
   if (connect_sock(local_addr, nfd, remote_addr_) != 0) {
     close(nfd);
     return -1;
   }
-#endif // !HAVE_LINUX_RTNETLINK_H
+#endif // !defined(HAVE_LINUX_RTNETLINK_H)
 
   if (!config.quiet) {
     std::cerr << "Local address is now "
@@ -1324,12 +1324,12 @@ int Client::change_local_addr() {
     ngtcp2_conn_set_path_user_data(conn_, &ep);
   } else {
     auto path = ngtcp2_path{
-        addr,
-        {
-            const_cast<sockaddr *>(&remote_addr_.su.sa),
-            remote_addr_.len,
-        },
-        &ep,
+      addr,
+      {
+        const_cast<sockaddr *>(&remote_addr_.su.sa),
+        remote_addr_.len,
+      },
+      &ep,
     };
     if (auto rv = ngtcp2_conn_initiate_immediate_migration(conn_, &path,
                                                            util::timestamp());
@@ -1421,7 +1421,7 @@ int Client::send_packet(const Endpoint &ep, const ngtcp2_addr &remote_addr,
 #ifdef HAVE_LINUX_RTNETLINK_H
   msg.msg_name = const_cast<sockaddr *>(remote_addr.addr);
   msg.msg_namelen = remote_addr.addrlen;
-#endif // HAVE_LINUX_RTNETLINK_H
+#endif // defined(HAVE_LINUX_RTNETLINK_H)
   msg.msg_iov = &msg_iov;
   msg.msg_iovlen = 1;
 
@@ -1514,8 +1514,8 @@ int Client::send_blocked_packet() {
   assert(tx_.send_blocked);
 
   ngtcp2_addr remote_addr{
-      .addr = &tx_.blocked.remote_addr.su.sa,
-      .addrlen = tx_.blocked.remote_addr.len,
+    .addr = &tx_.blocked.remote_addr.su.sa,
+    .addrlen = tx_.blocked.remote_addr.len,
   };
 
   auto rv = send_packet(*tx_.blocked.endpoint, remote_addr, tx_.blocked.ecn,
@@ -1553,8 +1553,8 @@ int Client::handle_error() {
   ngtcp2_pkt_info pi;
 
   auto nwrite = ngtcp2_conn_write_connection_close(
-      conn_, &ps.path, &pi, buf.data(), buf.size(), &last_error_,
-      util::timestamp());
+    conn_, &ps.path, &pi, buf.data(), buf.size(), &last_error_,
+    util::timestamp());
   if (nwrite < 0) {
     std::cerr << "ngtcp2_conn_write_connection_close: "
               << ngtcp2_strerror(nwrite) << std::endl;
@@ -1611,7 +1611,7 @@ int Client::on_extend_max_streams() {
     }
 
     auto stream = std::make_unique<Stream>(
-        config.requests[nstreams_done_ % config.requests.size()], stream_id);
+      config.requests[nstreams_done_ % config.requests.size()], stream_id);
 
     if (submit_http_request(stream.get()) != 0) {
       break;
@@ -1637,12 +1637,12 @@ int Client::submit_http_request(Stream *stream) {
   stream->reqbuf.begin = reinterpret_cast<uint8_t *>(stream->rawreqbuf.data());
   stream->reqbuf.pos = stream->reqbuf.begin;
   stream->reqbuf.end = stream->reqbuf.last =
-      stream->reqbuf.begin + stream->rawreqbuf.size();
+    stream->reqbuf.begin + stream->rawreqbuf.size();
 
   if (!config.quiet) {
     auto nva = std::to_array({
-        util::make_nv_nn(":method", config.http_method),
-        util::make_nv_nn(":path", req.path),
+      util::make_nv_nn(":method", config.http_method),
+      util::make_nv_nn(":path", req.path),
     });
     debug::print_http_request_headers(stream->stream_id, nva.data(),
                                       nva.size());
@@ -1709,9 +1709,9 @@ int Client::select_preferred_address(Address &selected_addr,
   }
 
   char host[NI_MAXHOST], service[NI_MAXSERV];
-  if (auto rv = getnameinfo(&selected_addr.su.sa, selected_addr.len, host,
-                            sizeof(host), service, sizeof(service),
-                            NI_NUMERICHOST | NI_NUMERICSERV);
+  if (auto rv =
+        getnameinfo(&selected_addr.su.sa, selected_addr.len, host, sizeof(host),
+                    service, sizeof(service), NI_NUMERICHOST | NI_NUMERICSERV);
       rv != 0) {
     std::cerr << "getnameinfo: " << gai_strerror(rv) << std::endl;
     return -1;
@@ -1752,12 +1752,12 @@ int run(Client &c, const char *addr, const char *port,
     close(fd);
     return -1;
   }
-#else  // !HAVE_LINUX_RTNETLINK_H
+#else  // !defined(HAVE_LINUX_RTNETLINK_H)
   if (connect_sock(local_addr, fd, remote_addr) != 0) {
     close(fd);
     return -1;
   }
-#endif // !HAVE_LINUX_RTNETLINK_H
+#endif // !defined(HAVE_LINUX_RTNETLINK_H)
 
   if (c.init(fd, local_addr, remote_addr, addr, port, tls_ctx) != 0) {
     return -1;
@@ -2116,58 +2116,58 @@ int main(int argc, char **argv) {
   for (;;) {
     static int flag = 0;
     constexpr static option long_opts[] = {
-        {"help", no_argument, nullptr, 'h'},
-        {"tx-loss", required_argument, nullptr, 't'},
-        {"rx-loss", required_argument, nullptr, 'r'},
-        {"data", required_argument, nullptr, 'd'},
-        {"http-method", required_argument, nullptr, 'm'},
-        {"nstreams", required_argument, nullptr, 'n'},
-        {"version", required_argument, nullptr, 'v'},
-        {"quiet", no_argument, nullptr, 'q'},
-        {"show-secret", no_argument, nullptr, 's'},
-        {"ciphers", required_argument, &flag, 1},
-        {"groups", required_argument, &flag, 2},
-        {"timeout", required_argument, &flag, 3},
-        {"session-file", required_argument, &flag, 4},
-        {"tp-file", required_argument, &flag, 5},
-        {"dcid", required_argument, &flag, 6},
-        {"change-local-addr", required_argument, &flag, 7},
-        {"key-update", required_argument, &flag, 8},
-        {"nat-rebinding", no_argument, &flag, 9},
-        {"delay-stream", required_argument, &flag, 10},
-        {"no-preferred-addr", no_argument, &flag, 11},
-        {"key", required_argument, &flag, 12},
-        {"cert", required_argument, &flag, 13},
-        {"download", required_argument, &flag, 14},
-        {"no-quic-dump", no_argument, &flag, 15},
-        {"no-http-dump", no_argument, &flag, 16},
-        {"qlog-file", required_argument, &flag, 17},
-        {"max-data", required_argument, &flag, 18},
-        {"max-stream-data-bidi-local", required_argument, &flag, 19},
-        {"max-stream-data-bidi-remote", required_argument, &flag, 20},
-        {"max-stream-data-uni", required_argument, &flag, 21},
-        {"max-streams-bidi", required_argument, &flag, 22},
-        {"max-streams-uni", required_argument, &flag, 23},
-        {"exit-on-first-stream-close", no_argument, &flag, 24},
-        {"disable-early-data", no_argument, &flag, 25},
-        {"qlog-dir", required_argument, &flag, 26},
-        {"cc", required_argument, &flag, 27},
-        {"exit-on-all-streams-close", no_argument, &flag, 28},
-        {"token-file", required_argument, &flag, 29},
-        {"sni", required_argument, &flag, 30},
-        {"initial-rtt", required_argument, &flag, 31},
-        {"max-window", required_argument, &flag, 32},
-        {"max-stream-window", required_argument, &flag, 33},
-        {"max-udp-payload-size", required_argument, &flag, 35},
-        {"handshake-timeout", required_argument, &flag, 36},
-        {"available-versions", required_argument, &flag, 37},
-        {"no-pmtud", no_argument, &flag, 38},
-        {"preferred-versions", required_argument, &flag, 39},
-        {"ack-thresh", required_argument, &flag, 40},
-        {"wait-for-ticket", no_argument, &flag, 41},
-        {"initial-pkt-num", required_argument, &flag, 42},
-        {"pmtud-probes", required_argument, &flag, 43},
-        {nullptr, 0, nullptr, 0},
+      {"help", no_argument, nullptr, 'h'},
+      {"tx-loss", required_argument, nullptr, 't'},
+      {"rx-loss", required_argument, nullptr, 'r'},
+      {"data", required_argument, nullptr, 'd'},
+      {"http-method", required_argument, nullptr, 'm'},
+      {"nstreams", required_argument, nullptr, 'n'},
+      {"version", required_argument, nullptr, 'v'},
+      {"quiet", no_argument, nullptr, 'q'},
+      {"show-secret", no_argument, nullptr, 's'},
+      {"ciphers", required_argument, &flag, 1},
+      {"groups", required_argument, &flag, 2},
+      {"timeout", required_argument, &flag, 3},
+      {"session-file", required_argument, &flag, 4},
+      {"tp-file", required_argument, &flag, 5},
+      {"dcid", required_argument, &flag, 6},
+      {"change-local-addr", required_argument, &flag, 7},
+      {"key-update", required_argument, &flag, 8},
+      {"nat-rebinding", no_argument, &flag, 9},
+      {"delay-stream", required_argument, &flag, 10},
+      {"no-preferred-addr", no_argument, &flag, 11},
+      {"key", required_argument, &flag, 12},
+      {"cert", required_argument, &flag, 13},
+      {"download", required_argument, &flag, 14},
+      {"no-quic-dump", no_argument, &flag, 15},
+      {"no-http-dump", no_argument, &flag, 16},
+      {"qlog-file", required_argument, &flag, 17},
+      {"max-data", required_argument, &flag, 18},
+      {"max-stream-data-bidi-local", required_argument, &flag, 19},
+      {"max-stream-data-bidi-remote", required_argument, &flag, 20},
+      {"max-stream-data-uni", required_argument, &flag, 21},
+      {"max-streams-bidi", required_argument, &flag, 22},
+      {"max-streams-uni", required_argument, &flag, 23},
+      {"exit-on-first-stream-close", no_argument, &flag, 24},
+      {"disable-early-data", no_argument, &flag, 25},
+      {"qlog-dir", required_argument, &flag, 26},
+      {"cc", required_argument, &flag, 27},
+      {"exit-on-all-streams-close", no_argument, &flag, 28},
+      {"token-file", required_argument, &flag, 29},
+      {"sni", required_argument, &flag, 30},
+      {"initial-rtt", required_argument, &flag, 31},
+      {"max-window", required_argument, &flag, 32},
+      {"max-stream-window", required_argument, &flag, 33},
+      {"max-udp-payload-size", required_argument, &flag, 35},
+      {"handshake-timeout", required_argument, &flag, 36},
+      {"available-versions", required_argument, &flag, 37},
+      {"no-pmtud", no_argument, &flag, 38},
+      {"preferred-versions", required_argument, &flag, 39},
+      {"ack-thresh", required_argument, &flag, 40},
+      {"wait-for-ticket", no_argument, &flag, 41},
+      {"initial-pkt-num", required_argument, &flag, 42},
+      {"pmtud-probes", required_argument, &flag, 43},
+      {nullptr, 0, nullptr, 0},
     };
 
     auto optidx = 0;
@@ -2243,6 +2243,10 @@ int main(int argc, char **argv) {
       switch (flag) {
       case 1:
         // --ciphers
+        if (util::crypto_default_ciphers()[0] == '\0') {
+          std::cerr << "ciphers: not supported" << std::endl;
+          exit(EXIT_FAILURE);
+        }
         config.ciphers = optarg;
         break;
       case 2:
@@ -2579,7 +2583,7 @@ int main(int argc, char **argv) {
           config.initial_pkt_num = static_cast<uint32_t>(*n);
         }
         break;
-      case 43:
+      case 43: {
         // --pmtud-probes
         auto l = util::split_str(optarg);
         for (auto &s : l) {
@@ -2588,8 +2592,8 @@ int main(int argc, char **argv) {
             exit(EXIT_FAILURE);
           } else if (*n <= 1200 || *n >= 64_k) {
             std::cerr
-                << "pmtud-probes: must be in range [1201, 65535], inclusive."
-                << std::endl;
+              << "pmtud-probes: must be in range [1201, 65535], inclusive."
+              << std::endl;
             exit(EXIT_FAILURE);
           } else {
             config.pmtud_probes.push_back(*n);
@@ -2597,6 +2601,7 @@ int main(int argc, char **argv) {
         }
         break;
       }
+      }
       break;
     default:
       break;
@@ -2722,8 +2727,8 @@ int main(int argc, char **argv) {
     }
 
     client_chosen_version = ngtcp2_select_version(
-        config.preferred_versions.data(), config.preferred_versions.size(),
-        offered_versions.data(), offered_versions.size());
+      config.preferred_versions.data(), config.preferred_versions.size(),
+      offered_versions.data(), offered_versions.size());
 
     if (client_chosen_version == 0) {
       std::cerr << "Unable to select a version" << std::endl;
