@@ -85,15 +85,13 @@ static int greater(const ngtcp2_ksl_key *lhs, const ngtcp2_ksl_key *rhs) {
   return *(int64_t *)lhs > *(int64_t *)rhs;
 }
 
-void ngtcp2_rtb_init(ngtcp2_rtb *rtb, ngtcp2_pktns_id pktns_id,
-                     ngtcp2_strm *crypto, ngtcp2_rst *rst, ngtcp2_cc *cc,
+void ngtcp2_rtb_init(ngtcp2_rtb *rtb, ngtcp2_rst *rst, ngtcp2_cc *cc,
                      int64_t cc_pkt_num, ngtcp2_log *log, ngtcp2_qlog *qlog,
                      ngtcp2_objalloc *rtb_entry_objalloc,
                      ngtcp2_objalloc *frc_objalloc, const ngtcp2_mem *mem) {
   rtb->rtb_entry_objalloc = rtb_entry_objalloc;
   rtb->frc_objalloc = frc_objalloc;
   ngtcp2_ksl_init(&rtb->ents, greater, sizeof(int64_t), mem);
-  rtb->crypto = crypto;
   rtb->rst = rst;
   rtb->cc = cc;
   rtb->log = log;
@@ -104,7 +102,6 @@ void ngtcp2_rtb_init(ngtcp2_rtb *rtb, ngtcp2_pktns_id pktns_id,
   rtb->num_retransmittable = 0;
   rtb->num_pto_eliciting = 0;
   rtb->probe_pkt_left = 0;
-  rtb->pktns_id = pktns_id;
   rtb->cc_pkt_num = cc_pkt_num;
   rtb->cc_bytes_in_flight = 0;
   rtb->persistent_congestion_start_ts = UINT64_MAX;
@@ -144,9 +141,11 @@ static void rtb_on_add(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
   if (ent->flags & NGTCP2_RTB_ENTRY_FLAG_ACK_ELICITING) {
     ++rtb->num_ack_eliciting;
   }
+
   if (ent->flags & NGTCP2_RTB_ENTRY_FLAG_RETRANSMITTABLE) {
     ++rtb->num_retransmittable;
   }
+
   if (ent->flags & NGTCP2_RTB_ENTRY_FLAG_PTO_ELICITING) {
     ++rtb->num_pto_eliciting;
   }
@@ -208,10 +207,10 @@ static size_t rtb_on_remove(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
 #define NGTCP2_RECLAIM_FLAG_ON_LOSS 0x01u
 
 /*
- * rtb_reclaim_frame queues unacknowledged frames included in |ent|
- * for retransmission.  The re-queued frames are not deleted from
- * |ent|.  It returns the number of frames queued.  |flags| is bitwise
- * OR of 0 or more of NGTCP2_RECLAIM_FLAG_*.
+ * rtb_reclaim_frame copies and queues frames included in |ent| for
+ * retransmission.  The frames are not deleted from |ent|.  It returns
+ * the number of frames queued.  |flags| is bitwise OR of 0 or more of
+ * NGTCP2_RECLAIM_FLAG_*.
  */
 static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
                                       ngtcp2_conn *conn, ngtcp2_pktns *pktns,
@@ -228,11 +227,13 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
   /* TODO Reconsider the order of pfrc */
   for (frc = ent->frc; frc; frc = frc->next) {
     fr = &frc->fr;
+
     /* Check that a late ACK acknowledged this frame. */
     if (frc->binder &&
         (frc->binder->flags & NGTCP2_FRAME_CHAIN_BINDER_FLAG_ACK)) {
       continue;
     }
+
     switch (frc->fr.type) {
     case NGTCP2_FRAME_STREAM:
       strm = ngtcp2_conn_find_stream(conn, fr->stream.stream_id);
@@ -243,14 +244,15 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
       gap = ngtcp2_strm_get_unacked_range_after(strm, fr->stream.offset);
 
       range.begin = fr->stream.offset;
-      range.end = fr->stream.offset +
-                  ngtcp2_vec_len(fr->stream.data, fr->stream.datacnt);
+      range.end =
+        fr->stream.offset + ngtcp2_vec_len(fr->stream.data, fr->stream.datacnt);
       range = ngtcp2_range_intersect(&range, &gap);
+
       if (ngtcp2_range_len(&range) == 0) {
         if (!fr->stream.fin) {
           /* 0 length STREAM frame with offset == 0 must be
-             retransmitted if no non-empty data is sent to this stream
-             and no data in this stream is acknowledged. */
+             retransmitted if no non-empty data are sent to this
+             stream, and no data in this stream are acknowledged. */
           if (fr->stream.offset != 0 || fr->stream.datacnt != 0 ||
               strm->tx.offset || (strm->flags & NGTCP2_STRM_FLAG_ANY_ACKED)) {
             continue;
@@ -267,7 +269,7 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
       }
 
       rv = ngtcp2_frame_chain_stream_datacnt_objalloc_new(
-          &nfrc, fr->stream.datacnt, rtb->frc_objalloc, rtb->mem);
+        &nfrc, fr->stream.datacnt, rtb->frc_objalloc, rtb->mem);
       if (rv != 0) {
         return rv;
       }
@@ -281,8 +283,10 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
         ngtcp2_frame_chain_objalloc_del(nfrc, rtb->frc_objalloc, rtb->mem);
         return rv;
       }
+
       if (!ngtcp2_strm_is_tx_queued(strm)) {
         strm->cycle = ngtcp2_conn_tx_strmq_first_cycle(conn);
+
         rv = ngtcp2_conn_tx_strmq_push(conn, strm);
         if (rv != 0) {
           return rv;
@@ -293,20 +297,22 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
 
       continue;
     case NGTCP2_FRAME_CRYPTO:
-      /* Don't resend CRYPTO frame if the whole region it contains has
-         been acknowledged */
-      gap = ngtcp2_strm_get_unacked_range_after(rtb->crypto, fr->stream.offset);
+      /* Do not resend CRYPTO frame if the whole region it contains
+         has been acknowledged */
+      gap = ngtcp2_strm_get_unacked_range_after(&pktns->crypto.strm,
+                                                fr->stream.offset);
 
       range.begin = fr->stream.offset;
-      range.end = fr->stream.offset +
-                  ngtcp2_vec_len(fr->stream.data, fr->stream.datacnt);
+      range.end =
+        fr->stream.offset + ngtcp2_vec_len(fr->stream.data, fr->stream.datacnt);
       range = ngtcp2_range_intersect(&range, &gap);
+
       if (ngtcp2_range_len(&range) == 0) {
         continue;
       }
 
       rv = ngtcp2_frame_chain_stream_datacnt_objalloc_new(
-          &nfrc, fr->stream.datacnt, rtb->frc_objalloc, rtb->mem);
+        &nfrc, fr->stream.datacnt, rtb->frc_objalloc, rtb->mem);
       if (rv != 0) {
         return rv;
       }
@@ -327,8 +333,8 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
       continue;
     case NGTCP2_FRAME_NEW_TOKEN:
       rv = ngtcp2_frame_chain_new_token_objalloc_new(
-          &nfrc, fr->new_token.token, fr->new_token.tokenlen, rtb->frc_objalloc,
-          rtb->mem);
+        &nfrc, fr->new_token.token, fr->new_token.tokenlen, rtb->frc_objalloc,
+        rtb->mem);
       if (rv != 0) {
         return rv;
       }
@@ -365,7 +371,7 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
     case NGTCP2_FRAME_MAX_STREAM_DATA:
       strm = ngtcp2_conn_find_stream(conn, fr->max_stream_data.stream_id);
       if (strm == NULL || !ngtcp2_strm_require_retransmit_max_stream_data(
-                              strm, &fr->max_stream_data)) {
+                            strm, &fr->max_stream_data)) {
         continue;
       }
 
@@ -373,7 +379,7 @@ static ngtcp2_ssize rtb_reclaim_frame(ngtcp2_rtb *rtb, uint8_t flags,
     case NGTCP2_FRAME_STREAM_DATA_BLOCKED:
       strm = ngtcp2_conn_find_stream(conn, fr->stream_data_blocked.stream_id);
       if (strm == NULL || !ngtcp2_strm_require_retransmit_stream_data_blocked(
-                              strm, &fr->stream_data_blocked)) {
+                            strm, &fr->stream_data_blocked)) {
         continue;
       }
 
@@ -422,6 +428,7 @@ static int conn_process_lost_datagram(ngtcp2_conn *conn,
       if (rv != 0) {
         return NGTCP2_ERR_CALLBACK_FAILURE;
       }
+
       break;
     }
   }
@@ -429,10 +436,9 @@ static int conn_process_lost_datagram(ngtcp2_conn *conn,
   return 0;
 }
 
-static int rtb_on_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_ksl_it *it,
-                           ngtcp2_rtb_entry *ent, ngtcp2_conn_stat *cstat,
-                           ngtcp2_conn *conn, ngtcp2_pktns *pktns,
-                           ngtcp2_tstamp ts) {
+static int rtb_on_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
+                           ngtcp2_conn_stat *cstat, ngtcp2_conn *conn,
+                           ngtcp2_pktns *pktns, ngtcp2_tstamp ts) {
   int rv;
   ngtcp2_ssize reclaimed;
   ngtcp2_cc *cc = rtb->cc;
@@ -450,7 +456,7 @@ static int rtb_on_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_ksl_it *it,
   } else if (rtb->cc->on_pkt_lost) {
     cc->on_pkt_lost(cc, cstat,
                     ngtcp2_cc_pkt_init(&pkt, ent->hd.pkt_num, ent->pktlen,
-                                       rtb->pktns_id, ent->ts, ent->rst.lost,
+                                       pktns->id, ent->ts, ent->rst.lost,
                                        ent->rst.tx_in_flight,
                                        ent->rst.is_app_limited),
                     ts);
@@ -462,34 +468,25 @@ static int rtb_on_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_ksl_it *it,
                     ent->hd.pkt_num);
     assert(!(ent->flags & NGTCP2_RTB_ENTRY_FLAG_LOST_RETRANSMITTED));
     assert(UINT64_MAX == ent->lost_ts);
-
-    ent->flags |= NGTCP2_RTB_ENTRY_FLAG_LOST_RETRANSMITTED;
-    ent->lost_ts = ts;
-
-    ++rtb->num_lost_pkts;
-
-    ngtcp2_ksl_it_next(it);
-
-    return 0;
-  }
-
-  if (conn->callbacks.lost_datagram &&
-      (ent->flags & NGTCP2_RTB_ENTRY_FLAG_DATAGRAM)) {
-    rv = conn_process_lost_datagram(conn, ent);
-    if (rv != 0) {
-      return rv;
+  } else {
+    if (conn->callbacks.lost_datagram &&
+        (ent->flags & NGTCP2_RTB_ENTRY_FLAG_DATAGRAM)) {
+      rv = conn_process_lost_datagram(conn, ent);
+      if (rv != 0) {
+        return rv;
+      }
     }
-  }
 
-  if (ent->flags & NGTCP2_RTB_ENTRY_FLAG_RETRANSMITTABLE) {
-    assert(ent->frc);
-    assert(!(ent->flags & NGTCP2_RTB_ENTRY_FLAG_LOST_RETRANSMITTED));
-    assert(UINT64_MAX == ent->lost_ts);
+    if (ent->flags & NGTCP2_RTB_ENTRY_FLAG_RETRANSMITTABLE) {
+      assert(ent->frc);
+      assert(!(ent->flags & NGTCP2_RTB_ENTRY_FLAG_LOST_RETRANSMITTED));
+      assert(UINT64_MAX == ent->lost_ts);
 
-    reclaimed =
+      reclaimed =
         rtb_reclaim_frame(rtb, NGTCP2_RECLAIM_FLAG_ON_LOSS, conn, pktns, ent);
-    if (reclaimed < 0) {
-      return (int)reclaimed;
+      if (reclaimed < 0) {
+        return (int)reclaimed;
+      }
     }
   }
 
@@ -498,8 +495,6 @@ static int rtb_on_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_ksl_it *it,
 
   ++rtb->num_lost_pkts;
 
-  ngtcp2_ksl_it_next(it);
-
   return 0;
 }
 
@@ -517,7 +512,7 @@ int ngtcp2_rtb_add(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
   return 0;
 }
 
-ngtcp2_ksl_it ngtcp2_rtb_head(ngtcp2_rtb *rtb) {
+ngtcp2_ksl_it ngtcp2_rtb_head(const ngtcp2_rtb *rtb) {
   return ngtcp2_ksl_begin(&rtb->ents);
 }
 
@@ -565,23 +560,24 @@ static void conn_ack_crypto_data(ngtcp2_conn *conn, ngtcp2_pktns *pktns,
   return;
 }
 
-static int rtb_process_acked_pkt(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
-                                 ngtcp2_conn *conn) {
+static int process_acked_pkt(ngtcp2_rtb_entry *ent, ngtcp2_conn *conn,
+                             ngtcp2_pktns *pktns) {
   ngtcp2_frame_chain *frc;
   uint64_t prev_stream_offset, stream_offset;
   ngtcp2_strm *strm;
   int rv;
   uint64_t datalen;
-  ngtcp2_strm *crypto = rtb->crypto;
-  ngtcp2_pktns *pktns = NULL;
+  ngtcp2_strm *crypto = &pktns->crypto.strm;
 
   if ((ent->flags & NGTCP2_RTB_ENTRY_FLAG_PMTUD_PROBE) && conn->pmtud &&
       conn->pmtud->tx_pkt_num <= ent->hd.pkt_num) {
     ngtcp2_pmtud_probe_success(conn->pmtud, ent->pktlen);
 
-    conn->dcid.current.max_udp_payload_size =
-        conn->cstat.max_tx_udp_payload_size =
-            ngtcp2_max(conn->dcid.current.max_udp_payload_size, ent->pktlen);
+    if (conn->dcid.current.max_udp_payload_size < ent->pktlen) {
+      conn->dcid.current.max_udp_payload_size = ent->pktlen;
+      conn->cstat.max_tx_udp_payload_size =
+        ngtcp2_conn_get_path_max_tx_udp_payload_size(conn);
+    }
 
     if (ngtcp2_pmtud_finished(conn->pmtud)) {
       ngtcp2_conn_stop_pmtud(conn);
@@ -611,23 +607,25 @@ static int rtb_process_acked_pkt(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
       }
 
       prev_stream_offset = ngtcp2_strm_get_acked_offset(strm);
+
       rv = ngtcp2_strm_ack_data(
-          strm, frc->fr.stream.offset,
-          ngtcp2_vec_len(frc->fr.stream.data, frc->fr.stream.datacnt));
+        strm, frc->fr.stream.offset,
+        ngtcp2_vec_len(frc->fr.stream.data, frc->fr.stream.datacnt));
       if (rv != 0) {
         return rv;
       }
 
       if (conn->callbacks.acked_stream_data_offset) {
         stream_offset = ngtcp2_strm_get_acked_offset(strm);
+
         datalen = stream_offset - prev_stream_offset;
         if (datalen == 0 && !frc->fr.stream.fin) {
           break;
         }
 
         rv = conn->callbacks.acked_stream_data_offset(
-            conn, strm->stream_id, prev_stream_offset, datalen, conn->user_data,
-            strm->stream_user_data);
+          conn, strm->stream_id, prev_stream_offset, datalen, conn->user_data,
+          strm->stream_user_data);
         if (rv != 0) {
           return NGTCP2_ERR_CALLBACK_FAILURE;
         }
@@ -637,36 +635,25 @@ static int rtb_process_acked_pkt(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
       if (rv != 0) {
         return rv;
       }
+
       break;
     case NGTCP2_FRAME_CRYPTO:
       prev_stream_offset = ngtcp2_strm_get_acked_offset(crypto);
+
       rv = ngtcp2_strm_ack_data(
-          crypto, frc->fr.stream.offset,
-          ngtcp2_vec_len(frc->fr.stream.data, frc->fr.stream.datacnt));
+        crypto, frc->fr.stream.offset,
+        ngtcp2_vec_len(frc->fr.stream.data, frc->fr.stream.datacnt));
       if (rv != 0) {
         return rv;
       }
 
       stream_offset = ngtcp2_strm_get_acked_offset(crypto);
+
       datalen = stream_offset - prev_stream_offset;
       if (datalen == 0) {
         break;
       }
 
-      switch (rtb->pktns_id) {
-      case NGTCP2_PKTNS_ID_INITIAL:
-        pktns = conn->in_pktns;
-        break;
-      case NGTCP2_PKTNS_ID_HANDSHAKE:
-        pktns = conn->hs_pktns;
-        break;
-      case NGTCP2_PKTNS_ID_APPLICATION:
-        pktns = &conn->pktns;
-        break;
-      default:
-        ngtcp2_unreachable();
-      }
-
       conn_ack_crypto_data(conn, pktns, datalen);
 
       break;
@@ -675,11 +662,14 @@ static int rtb_process_acked_pkt(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
       if (strm == NULL) {
         break;
       }
+
       strm->flags |= NGTCP2_STRM_FLAG_RESET_STREAM_ACKED;
+
       rv = ngtcp2_conn_close_stream_if_shut_rdwr(conn, strm);
       if (rv != 0) {
         return rv;
       }
+
       break;
     case NGTCP2_FRAME_RETIRE_CONNECTION_ID:
       ngtcp2_conn_untrack_retired_dcid_seq(conn,
@@ -702,14 +692,17 @@ static int rtb_process_acked_pkt(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
       if (rv != 0) {
         return NGTCP2_ERR_CALLBACK_FAILURE;
       }
+
       break;
     }
   }
+
   return 0;
 }
 
 static void rtb_on_pkt_acked(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
-                             ngtcp2_conn_stat *cstat, ngtcp2_tstamp ts) {
+                             ngtcp2_conn_stat *cstat, const ngtcp2_pktns *pktns,
+                             ngtcp2_tstamp ts) {
   ngtcp2_cc *cc = rtb->cc;
   ngtcp2_cc_pkt pkt;
 
@@ -718,7 +711,7 @@ static void rtb_on_pkt_acked(ngtcp2_rtb *rtb, ngtcp2_rtb_entry *ent,
   if (cc->on_pkt_acked) {
     cc->on_pkt_acked(cc, cstat,
                      ngtcp2_cc_pkt_init(&pkt, ent->hd.pkt_num, ent->pktlen,
-                                        rtb->pktns_id, ent->ts, ent->rst.lost,
+                                        pktns->id, ent->ts, ent->rst.lost,
                                         ent->rst.tx_in_flight,
                                         ent->rst.is_app_limited),
                      ts);
@@ -745,12 +738,13 @@ static void conn_verify_ecn(ngtcp2_conn *conn, ngtcp2_pktns *pktns,
         pktns->rx.ecn.ack.ect1 > fr->ecn.ect1 ||
         pktns->rx.ecn.ack.ce > fr->ecn.ce ||
         (fr->ecn.ect0 - pktns->rx.ecn.ack.ect0) +
-                (fr->ecn.ce - pktns->rx.ecn.ack.ce) <
-            ecn_acked ||
+            (fr->ecn.ce - pktns->rx.ecn.ack.ce) <
+          ecn_acked ||
         fr->ecn.ect0 > pktns->tx.ecn.ect0 || fr->ecn.ect1))) {
     ngtcp2_log_info(&conn->log, NGTCP2_LOG_EVENT_CON,
                     "path is not ECN capable");
     conn->tx.ecn.state = NGTCP2_ECN_STATE_FAILED;
+
     return;
   }
 
@@ -762,7 +756,7 @@ static void conn_verify_ecn(ngtcp2_conn *conn, ngtcp2_pktns *pktns,
   if (fr->type == NGTCP2_FRAME_ACK_ECN) {
     if (cc->congestion_event && largest_pkt_sent_ts != UINT64_MAX &&
         fr->ecn.ce > pktns->rx.ecn.ack.ce) {
-      cc->congestion_event(cc, cstat, largest_pkt_sent_ts, ts);
+      cc->congestion_event(cc, cstat, largest_pkt_sent_ts, 0, ts);
     }
 
     pktns->rx.ecn.ack.ect0 = fr->ecn.ect0;
@@ -784,7 +778,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
   size_t i;
   int rv;
   ngtcp2_ksl_it it;
-  ngtcp2_ssize num_acked = 0;
+  size_t num_acked = 0;
   ngtcp2_tstamp largest_pkt_sent_ts = UINT64_MAX;
   int64_t pkt_num;
   ngtcp2_cc *cc = rtb->cc;
@@ -820,6 +814,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
       conn_verify_ecn(conn, pktns, rtb->cc, cstat, fr, ecn_acked,
                       largest_pkt_sent_ts, ts);
     }
+
     return 0;
   }
 
@@ -848,7 +843,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
     ++num_acked;
   }
 
-  for (i = 0; i < fr->rangecnt;) {
+  for (i = 0; i < fr->rangecnt; ++i) {
     largest_ack = min_ack - (int64_t)fr->ranges[i].gap - 2;
     min_ack = largest_ack - (int64_t)fr->ranges[i].len;
 
@@ -862,6 +857,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
       if (pkt_num < min_ack) {
         break;
       }
+
       ent = ngtcp2_ksl_it_get(&it);
 
       if (ent->flags & NGTCP2_RTB_ENTRY_FLAG_ACK_ELICITING) {
@@ -871,8 +867,6 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
       rtb_remove(rtb, &it, &acked_ent, ent, cstat);
       ++num_acked;
     }
-
-    ++i;
   }
 
   if (largest_pkt_sent_ts != UINT64_MAX && ack_eliciting_pkt_acked) {
@@ -891,7 +885,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
         ++ecn_acked;
       }
 
-      rv = rtb_process_acked_pkt(rtb, ent, conn);
+      rv = process_acked_pkt(ent, conn, pktns);
       if (rv != 0) {
         goto fail;
       }
@@ -903,7 +897,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
         cc_ack.pkt_delivered = ent->rst.delivered;
       }
 
-      rtb_on_pkt_acked(rtb, ent, cstat, ts);
+      rtb_on_pkt_acked(rtb, ent, cstat, pktns, ts);
       acked_ent = ent->next;
       ngtcp2_rtb_entry_objalloc_del(ent, rtb->rtb_entry_objalloc,
                                     rtb->frc_objalloc, rtb->mem);
@@ -916,7 +910,7 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
   } else {
     /* For unit tests */
     for (ent = acked_ent; ent; ent = acked_ent) {
-      rtb_on_pkt_acked(rtb, ent, cstat, ts);
+      rtb_on_pkt_acked(rtb, ent, cstat, pktns, ts);
       acked_ent = ent->next;
       ngtcp2_rtb_entry_objalloc_del(ent, rtb->rtb_entry_objalloc,
                                     rtb->frc_objalloc, rtb->mem);
@@ -924,27 +918,29 @@ ngtcp2_ssize ngtcp2_rtb_recv_ack(ngtcp2_rtb *rtb, const ngtcp2_ack *fr,
   }
 
   if (rtb->cc->on_spurious_congestion && num_lost_pkts &&
-      rtb->num_lost_pkts - rtb->num_lost_pmtud_pkts == 0) {
+      rtb->num_lost_pkts == rtb->num_lost_pmtud_pkts) {
     rtb->cc->on_spurious_congestion(cc, cstat, ts);
   }
 
-  ngtcp2_rst_on_ack_recv(rtb->rst, cstat, cc_ack.pkt_delivered);
+  if (num_acked) {
+    ngtcp2_rst_on_ack_recv(rtb->rst, cstat);
 
-  if (conn && num_acked > 0) {
-    rv = rtb_detect_lost_pkt(rtb, &cc_ack.bytes_lost, conn, pktns, cstat, ts);
-    if (rv != 0) {
-      return rv;
+    if (conn) {
+      rv = rtb_detect_lost_pkt(rtb, &cc_ack.bytes_lost, conn, pktns, cstat, ts);
+      if (rv != 0) {
+        return rv;
+      }
     }
   }
 
   rtb->rst->lost += cc_ack.bytes_lost;
 
   cc_ack.largest_pkt_sent_ts = largest_pkt_sent_ts;
-  if (cc->on_ack_recv) {
+  if (num_acked && cc->on_ack_recv) {
     cc->on_ack_recv(cc, cstat, &cc_ack, ts);
   }
 
-  return num_acked;
+  return (ngtcp2_ssize)num_acked;
 
 fail:
   for (ent = acked_ent; ent; ent = acked_ent) {
@@ -958,7 +954,8 @@ fail:
 
 static int rtb_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_conn_stat *cstat,
                         const ngtcp2_rtb_entry *ent, ngtcp2_duration loss_delay,
-                        size_t pkt_thres, ngtcp2_tstamp ts) {
+                        size_t pkt_thres, const ngtcp2_pktns *pktns,
+                        ngtcp2_tstamp ts) {
   ngtcp2_tstamp loss_time;
 
   if (ngtcp2_tstamp_elapsed(ent->ts, loss_delay, ts) ||
@@ -966,7 +963,7 @@ static int rtb_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_conn_stat *cstat,
     return 1;
   }
 
-  loss_time = cstat->loss_time[rtb->pktns_id];
+  loss_time = cstat->loss_time[pktns->id];
 
   if (loss_time == UINT64_MAX) {
     loss_time = ent->ts + loss_delay;
@@ -974,19 +971,19 @@ static int rtb_pkt_lost(ngtcp2_rtb *rtb, ngtcp2_conn_stat *cstat,
     loss_time = ngtcp2_min_uint64(loss_time, ent->ts + loss_delay);
   }
 
-  cstat->loss_time[rtb->pktns_id] = loss_time;
+  cstat->loss_time[pktns->id] = loss_time;
 
   return 0;
 }
 
 /*
- * rtb_compute_pkt_loss_delay computes loss delay.
+ * compute_pkt_loss_delay computes loss delay.
  */
 static ngtcp2_duration compute_pkt_loss_delay(const ngtcp2_conn_stat *cstat) {
   /* 9/8 is kTimeThreshold */
   ngtcp2_duration loss_delay =
-      ngtcp2_max(cstat->latest_rtt, cstat->smoothed_rtt) * 9 / 8;
-  return ngtcp2_max(loss_delay, NGTCP2_GRANULARITY);
+    ngtcp2_max_uint64(cstat->latest_rtt, cstat->smoothed_rtt) * 9 / 8;
+  return ngtcp2_max_uint64(loss_delay, NGTCP2_GRANULARITY);
 }
 
 /*
@@ -999,9 +996,9 @@ static int conn_all_ecn_pkt_lost(ngtcp2_conn *conn) {
   ngtcp2_pktns *pktns = &conn->pktns;
 
   return (!in_pktns || in_pktns->tx.ecn.validation_pkt_sent ==
-                           in_pktns->tx.ecn.validation_pkt_lost) &&
+                         in_pktns->tx.ecn.validation_pkt_lost) &&
          (!hs_pktns || hs_pktns->tx.ecn.validation_pkt_sent ==
-                           hs_pktns->tx.ecn.validation_pkt_lost) &&
+                         hs_pktns->tx.ecn.validation_pkt_lost) &&
          pktns->tx.ecn.validation_pkt_sent == pktns->tx.ecn.validation_pkt_lost;
 }
 
@@ -1017,16 +1014,16 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
   ngtcp2_cc *cc = rtb->cc;
   int rv;
   uint64_t pkt_thres =
-      rtb->cc_bytes_in_flight / cstat->max_tx_udp_payload_size / 2;
+    rtb->cc_bytes_in_flight / cstat->max_tx_udp_payload_size / 2;
   size_t ecn_pkt_lost = 0;
   ngtcp2_tstamp start_ts;
   ngtcp2_duration pto = ngtcp2_conn_compute_pto(conn, pktns);
   uint64_t bytes_lost = 0;
   ngtcp2_duration max_ack_delay;
 
-  pkt_thres = ngtcp2_max(pkt_thres, NGTCP2_PKT_THRESHOLD);
-  pkt_thres = ngtcp2_min(pkt_thres, 256);
-  cstat->loss_time[rtb->pktns_id] = UINT64_MAX;
+  pkt_thres = ngtcp2_max_uint64(pkt_thres, NGTCP2_PKT_THRESHOLD);
+  pkt_thres = ngtcp2_min_uint64(pkt_thres, 256);
+  cstat->loss_time[pktns->id] = UINT64_MAX;
   loss_delay = compute_pkt_loss_delay(cstat);
 
   it = ngtcp2_ksl_lower_bound(&rtb->ents, &rtb->largest_acked_tx_pkt_num);
@@ -1037,26 +1034,27 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
       break;
     }
 
-    if (rtb_pkt_lost(rtb, cstat, ent, loss_delay, (size_t)pkt_thres, ts)) {
+    if (rtb_pkt_lost(rtb, cstat, ent, loss_delay, (size_t)pkt_thres, pktns,
+                     ts)) {
       /* All entries from ent are considered to be lost. */
       latest_ts = oldest_ts = ent->ts;
       /* +1 to pick this packet for persistent congestion in the
          following loop. */
       last_lost_pkt_num = ent->hd.pkt_num + 1;
       max_ack_delay = conn->remote.transport_params
-                          ? conn->remote.transport_params->max_ack_delay
-                          : 0;
+                        ? conn->remote.transport_params->max_ack_delay
+                        : 0;
 
       congestion_period =
-          (cstat->smoothed_rtt +
-           ngtcp2_max_uint64(4 * cstat->rttvar, NGTCP2_GRANULARITY) +
-           max_ack_delay) *
-          NGTCP2_PERSISTENT_CONGESTION_THRESHOLD;
+        (cstat->smoothed_rtt +
+         ngtcp2_max_uint64(4 * cstat->rttvar, NGTCP2_GRANULARITY) +
+         max_ack_delay) *
+        NGTCP2_PERSISTENT_CONGESTION_THRESHOLD;
 
-      start_ts = ngtcp2_max(rtb->persistent_congestion_start_ts,
-                            cstat->first_rtt_sample_ts);
+      start_ts = ngtcp2_max_uint64(rtb->persistent_congestion_start_ts,
+                                   cstat->first_rtt_sample_ts);
 
-      for (; !ngtcp2_ksl_it_end(&it);) {
+      for (; !ngtcp2_ksl_it_end(&it); ngtcp2_ksl_it_next(&it)) {
         ent = ngtcp2_ksl_it_get(&it);
 
         if (last_lost_pkt_num == ent->hd.pkt_num + 1 && ent->ts >= start_ts) {
@@ -1067,12 +1065,12 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
         }
 
         if ((ent->flags & NGTCP2_RTB_ENTRY_FLAG_LOST_RETRANSMITTED)) {
-          if (rtb->pktns_id != NGTCP2_PKTNS_ID_APPLICATION ||
+          if (pktns->id != NGTCP2_PKTNS_ID_APPLICATION ||
               last_lost_pkt_num == -1 ||
               latest_ts - oldest_ts >= congestion_period) {
             break;
           }
-          ngtcp2_ksl_it_next(&it);
+
           continue;
         }
 
@@ -1082,7 +1080,7 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
         }
 
         bytes_lost += rtb_on_remove(rtb, ent, cstat);
-        rv = rtb_on_pkt_lost(rtb, &it, ent, cstat, conn, pktns, ts);
+        rv = rtb_on_pkt_lost(rtb, ent, cstat, conn, pktns, ts);
         if (rv != 0) {
           return rv;
         }
@@ -1099,13 +1097,16 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
         if (conn->tx.ecn.validation_start_ts == UINT64_MAX) {
           break;
         }
+
         if (ts - conn->tx.ecn.validation_start_ts < 3 * pto) {
           pktns->tx.ecn.validation_pkt_lost += ecn_pkt_lost;
           assert(pktns->tx.ecn.validation_pkt_sent >=
                  pktns->tx.ecn.validation_pkt_lost);
           break;
         }
+
         conn->tx.ecn.state = NGTCP2_ECN_STATE_UNKNOWN;
+
         /* fall through */
       case NGTCP2_ECN_STATE_UNKNOWN:
         pktns->tx.ecn.validation_pkt_lost += ecn_pkt_lost;
@@ -1120,7 +1121,7 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
       }
 
       if (cc->congestion_event) {
-        cc->congestion_event(cc, cstat, latest_ts, ts);
+        cc->congestion_event(cc, cstat, latest_ts, bytes_lost, ts);
       }
 
       loss_window = latest_ts - oldest_ts;
@@ -1131,23 +1132,22 @@ static int rtb_detect_lost_pkt(ngtcp2_rtb *rtb, uint64_t *ppkt_lost,
        * persistent congestion there, then it is a lot easier to just
        * not enable it during handshake.
        */
-      if (rtb->pktns_id == NGTCP2_PKTNS_ID_APPLICATION && loss_window > 0) {
-        if (loss_window >= congestion_period) {
-          ngtcp2_log_info(rtb->log, NGTCP2_LOG_EVENT_LDC,
-                          "persistent congestion loss_window=%" PRIu64
-                          " congestion_period=%" PRIu64,
-                          loss_window, congestion_period);
+      if (pktns->id == NGTCP2_PKTNS_ID_APPLICATION && loss_window &&
+          loss_window >= congestion_period) {
+        ngtcp2_log_info(rtb->log, NGTCP2_LOG_EVENT_LDC,
+                        "persistent congestion loss_window=%" PRIu64
+                        " congestion_period=%" PRIu64,
+                        loss_window, congestion_period);
 
-          /* Reset min_rtt, srtt, and rttvar here.  Next new RTT
-             sample will be used to recalculate these values. */
-          cstat->min_rtt = UINT64_MAX;
-          cstat->smoothed_rtt = conn->local.settings.initial_rtt;
-          cstat->rttvar = conn->local.settings.initial_rtt / 2;
-          cstat->first_rtt_sample_ts = UINT64_MAX;
+        /* Reset min_rtt, srtt, and rttvar here.  Next new RTT
+           sample will be used to recalculate these values. */
+        cstat->min_rtt = UINT64_MAX;
+        cstat->smoothed_rtt = conn->local.settings.initial_rtt;
+        cstat->rttvar = conn->local.settings.initial_rtt / 2;
+        cstat->first_rtt_sample_ts = UINT64_MAX;
 
-          if (cc->on_persistent_congestion) {
-            cc->on_persistent_congestion(cc, cstat, ts);
-          }
+        if (cc->on_persistent_congestion) {
+          cc->on_persistent_congestion(cc, cstat, ts);
         }
       }
 
@@ -1244,7 +1244,7 @@ void ngtcp2_rtb_remove_expired_lost_pkt(ngtcp2_rtb *rtb, ngtcp2_duration pto,
   }
 }
 
-ngtcp2_tstamp ngtcp2_rtb_lost_pkt_ts(ngtcp2_rtb *rtb) {
+ngtcp2_tstamp ngtcp2_rtb_lost_pkt_ts(const ngtcp2_rtb *rtb) {
   ngtcp2_ksl_it it;
   ngtcp2_rtb_entry *ent;
 
@@ -1339,11 +1339,13 @@ static int rtb_on_pkt_lost_resched_move(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
         ngtcp2_frame_chain_objalloc_del(frc, rtb->frc_objalloc, rtb->mem);
         break;
       }
+
       rv = ngtcp2_strm_streamfrq_push(strm, frc);
       if (rv != 0) {
         ngtcp2_frame_chain_objalloc_del(frc, rtb->frc_objalloc, rtb->mem);
         return rv;
       }
+
       if (!ngtcp2_strm_is_tx_queued(strm)) {
         strm->cycle = ngtcp2_conn_tx_strmq_first_cycle(conn);
         rv = ngtcp2_conn_tx_strmq_push(conn, strm);
@@ -1351,6 +1353,7 @@ static int rtb_on_pkt_lost_resched_move(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
           return rv;
         }
       }
+
       break;
     case NGTCP2_FRAME_CRYPTO:
       frc = *pfrc;
@@ -1364,6 +1367,7 @@ static int rtb_on_pkt_lost_resched_move(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
         ngtcp2_frame_chain_objalloc_del(frc, rtb->frc_objalloc, rtb->mem);
         return rv;
       }
+
       break;
     case NGTCP2_FRAME_DATAGRAM:
     case NGTCP2_FRAME_DATAGRAM_LEN:
@@ -1380,6 +1384,7 @@ static int rtb_on_pkt_lost_resched_move(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
       *pfrc = (*pfrc)->next;
 
       ngtcp2_frame_chain_objalloc_del(frc, rtb->frc_objalloc, rtb->mem);
+
       break;
     default:
       pfrc = &(*pfrc)->next;
@@ -1409,8 +1414,10 @@ int ngtcp2_rtb_remove_all(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
     assert(0 == rv);
 
     rv = rtb_on_pkt_lost_resched_move(rtb, conn, pktns, ent);
+
     ngtcp2_rtb_entry_objalloc_del(ent, rtb->rtb_entry_objalloc,
                                   rtb->frc_objalloc, rtb->mem);
+
     if (rv != 0) {
       return rv;
     }
@@ -1444,7 +1451,7 @@ void ngtcp2_rtb_remove_early_data(ngtcp2_rtb *rtb, ngtcp2_conn_stat *cstat) {
   }
 }
 
-int ngtcp2_rtb_empty(ngtcp2_rtb *rtb) {
+int ngtcp2_rtb_empty(const ngtcp2_rtb *rtb) {
   return ngtcp2_ksl_len(&rtb->ents) == 0;
 }
 
@@ -1461,7 +1468,7 @@ ngtcp2_ssize ngtcp2_rtb_reclaim_on_pto(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
   size_t atmost = num_pkts;
 
   it = ngtcp2_ksl_end(&rtb->ents);
-  for (; !ngtcp2_ksl_it_begin(&it) && num_pkts >= 1;) {
+  for (; !ngtcp2_ksl_it_begin(&it) && num_pkts;) {
     ngtcp2_ksl_it_prev(&it);
     ent = ngtcp2_ksl_it_get(&it);
 
@@ -1474,13 +1481,13 @@ ngtcp2_ssize ngtcp2_rtb_reclaim_on_pto(ngtcp2_rtb *rtb, ngtcp2_conn *conn,
     assert(ent->frc);
 
     reclaimed =
-        rtb_reclaim_frame(rtb, NGTCP2_RECLAIM_FLAG_NONE, conn, pktns, ent);
+      rtb_reclaim_frame(rtb, NGTCP2_RECLAIM_FLAG_NONE, conn, pktns, ent);
     if (reclaimed < 0) {
       return reclaimed;
     }
 
-    /* Mark reclaimed even if reclaimed == 0 so that we can skip it in
-       the next run. */
+    /* Mark ent reclaimed even if reclaimed == 0 so that we can skip
+       it in the next run. */
     ent->flags |= NGTCP2_RTB_ENTRY_FLAG_PTO_RECLAIMED;
 
     assert(rtb->num_retransmittable);
